@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: Debug.pm,v 1.38 2010-07-03 00:57:10 dpchrist Exp $
+# $Id: Debug.pm,v 1.39 2010-11-06 01:05:06 dpchrist Exp $
 #######################################################################
 # package/ uses/ requires:
 #----------------------------------------------------------------------
@@ -36,11 +36,11 @@ our @EXPORT = qw(
 
 our @ISA = qw(Exporter);
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.38 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.39 $ =~ /(\d+)/g);
 
-my @used_only_once_workaround = (
-    $main::debug,
-);
+#my @used_only_once_workaround = (
+#    $main::debug,
+#);
 
 #######################################################################
 
@@ -165,7 +165,8 @@ sub debug_enabled()
 
   DONE:
 
-    return $r;
+    $r =~ /(.*)/;
+    return $1;
 }
 
 #######################################################################
